/*
	File:			CASessn.h

	Contains:		CASession interface

	Written by:	Rick Badertscher

	Copyright:	 1993-95 by Apple Computer, Inc., all rights reserved.

	Change History (most recent first):

		 <0>	  7/20/95	RB		Created


	To Do:
*/

#ifndef _CASESSN_
#define _CASESSN_

#ifndef _CADEFS_
#include "CADefs.h"
#endif

//==============================================================================
// Theory of Operation
//==============================================================================

//-------------------------------------------------------------------------------------
// Menus
//-------------------------------------------------------------------------------------


//==============================================================================
// Classes defined in this interface
//==============================================================================

class CASession;

//==============================================================================
// Classes (potentially) used by this interface
//==============================================================================

class ODSession;
class ODWindowState;
class ODWindow;
class ODDocument;
class ODContainer;
class ODMenuBar;
class PlatformFile;
class CADocument;
class CADragDropDocument;
class CAClipboardDocument;
class CADispatcher;
class OrderedCollection;
class ShellSI;

//=========================================================================
// Instance variables - need to be hidden from CA Implementors
//=========================================================================

extern	Boolean			_gCAInitted;
extern	CASession*		gCASession;
extern	OSErr			gCAError;


//==============================================================================
// CASession
//==============================================================================


class CASession
{

	public:

							CASession();
							~CASession();


	inline	ODSession*				GetODSession(	void)		{ return fSession;}	
	inline	ODWindowState*			GetWindowState(	void)		{ return fWindowState;}	
	inline	ODArbitrator*			GetArbitrator(	void)		{ return fArbitrator;}	

//-------------------------------------------------------------------------------------
// Initialization
//-------------------------------------------------------------------------------------

			void					Initialize();
			void 					InstallMenuBar(ODPlatformMenuBar menuBar);

	inline	Environment*			GetEV(void)					{return fEV;}
	
	inline	CADispatcher*			GetCADispatcher(void)		{return fCADispatcher;}

	// A nopart is created which app floaters are register with
	
			ODPart*					GetFloatingWindowHandlerPart (void);

	
			void					AddCADocumentRef(			CADocument*		docRef);
			void					RemoveCADocumentRef(		CADocument*		docRef);
			CADocument*				FindCADocumentRefForDraft(	ODDraft*		draft);
			CADocument*				FindCADocumentRefForWindow(	ODWindow*		window);
			Boolean					HaveCADocumentRef(			CADocumentRef document);

			CADragDropDocument*		GetCADragDropDocument(		void);
			CAClipboardDocument*	GetCAClipboardDocument(		void);

			// Menu stuff
	
			void					UpdateUndoMenus(			void);
			void					UpdateMenus(				void);
	
			void					RegisterCommand(			CACommandID command,
																CAMenuID menu,
																CAMenuItemID menuItem );
														
			Boolean					HandleMenuCommand(			ODSLong menuResult, ODEventData* event);


//-------------------------------------------------------------------------------------
// private fields
//-------------------------------------------------------------------------------------

private:

	struct MenuItemInfo
	{
		Str255	text;
		short	cmdChar;
		short	iconID;
		short	markChar;
		Style	textStyle;
	};

	Environment*			fEV;
	ODSession* 				fSession;
	ODWindowState* 			fWindowState;
	ODArbitrator* 			fArbitrator;
	CADispatcher*			fCADispatcher;

	ODPart*					fFloatingWindowPart;
	ODDraft*				fFloatingWindowPartDraft;
	ODHandle				fFloatingWindowCtrHandle;
	
	OrderedCollection*		fOpenCADocuments;			// CADocumentRef collection
	
	CADragDropDocument* 	fCADragDropDocument;
	CAClipboardDocument*	fCAClipboardDocument;

	MenuItemInfo			fDefaultAboutMenuItem;
	MenuItemInfo			fDefaultUndoMenuItem;
	MenuItemInfo			fDefaultRedoMenuItem;

	ShellSI*				fShellSemtInterface;
};

#endif
